@@ -8,7 +8,6 @@ $parser->opts('disjunct_cost' => 2);
 $parser->opts('linkage_limit' => 101);
 
 while (1) {
-
   print "Enter a sentence: ";
   $text = <STDIN>;
   my $sentence = $parser->create_sentence($text);
@@ -16,7 +15,9 @@ while (1) {
   for $i (1 .. $sentence->num_linkages) {
       $linkage = $sentence->linkage($i);
       $linkage->compute_union;
-      print $parser->get_diagram($linkage);
+      $sublinkage = $linkage->sublinkage($linkage->num_sublinkages);
+      print $parser->get_diagram($sublinkage);
+      print $sublinkage;
   }
 }
 
